==> moodle-2.9.1.tgz: moodle/theme/more/lang/en/theme_more.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Theme More lang file.
 *
 * @package    theme_more
 * @copyright  2014 Frédéric Massart
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['backgroundfixed'] = 'Background fixed';
$string['backgroundfixed_desc'] = 'Use this setting to fix the background image to the page.';
$string['backgroundimage'] = 'Background image';
$string['backgroundimage_desc'] = 'The image to display as a background of the site.';
$string['backgroundposition'] = 'Background position';
$string['backgroundposition_desc'] = 'The position of the background image.';
$string['backgroundpositioncenterbottom'] = 'Center bottom';
$string['backgroundpositioncentercenter'] = 'Center center';
$string['backgroundpositioncentertop'] = 'Center top';
$string['backgroundpositionleftbottom'] = 'Left bottom';
$string['backgroundpositionleftcenter'] = 'Left center';
$string['backgroundpositionlefttop'] = 'Left top';
$string['backgroundpositionrightbottom'] = 'Right bottom';
$string['backgroundpositionrightcenter'] = 'Right center';
$string['backgroundpositionrighttop'] = 'Right top';
$string['backgroundrepeat'] = 'Background repeat';
$string['backgroundrepeat_desc'] = 'Defines the way the background image will be repeated.';
$string['backgroundrepeatnorepeat'] = 'No repeat';
$string['backgroundrepeatrepeat'] = 'Repeat';
$string['backgroundrepeatrepeatx'] = 'Repeat horizontally';
$string['backgroundrepeatrepeaty'] = 'Repeat vertically';
$string['bodybackground'] = 'Background colour';
$string['bodybackground_desc'] = 'The main colour to use for the background.';
$string['choosereadme'] = '<p>More is a theme that allows you to easily customise Moodle\'s look and feel directly from the web interface.</p>
<p>Visit the admin settings to change colours, add an image as a background, add your logo and more.</p>';

$string['configtitle'] = 'More';
$string['contentbackground'] = 'Main content background colour';
$string['contentbackground_desc'] = 'The background colour of the main content of the site, leave empty for none.';

$string['customcss'] = 'Custom CSS';
$string['customcssdesc'] = 'Whatever CSS rules you add to this textarea will be reflected in every page, making for easier customization of this theme.';

$string['footnote'] = 'Footnote';
$string['footnotedesc'] = 'Whatever you add to this textarea will be displayed in the footer throughout your Moodle site.';

$string['invert'] = 'Invert navbar';
$string['invertdesc'] = 'Swaps text and background for the navbar at the top of the page between black and white.';

$string['linkcolor'] = 'Link colour';
$string['linkcolor_desc'] = 'The colour of the links.';
$string['logo'] = 'Logo';
$string['logodesc'] = 'The logo is displayed in the header.<br /> If the height of your logo is more than 75px add div.logo {height: 100px;} to the Custom CSS box below, amending accordingly if the height is other than 100px.';

$string['pluginname'] = 'More';

$string['region-side-post'] = 'Right';
$string['region-side-pre'] = 'Left';
$string['secondarybackground'] = 'Secondary background colour';
$string['secondarybackground_desc'] = 'The background colour of any secondary content, such as blocks.';
$string['textcolor'] = 'Text colour';
$string['textcolor_desc'] = 'The colour of the text.';

==> moodle-3.4.tgz: moodle/theme/more/lang/en/theme_more.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Theme More lang file.
 *
 * @package    theme_more
 * @copyright  2014 Frédéric Massart
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['backgroundfixed'] = 'Background fixed';
$string['backgroundfixed_desc'] = 'Use this setting to fix the background image to the page.';
$string['backgroundimage'] = 'Background image';
$string['backgroundimage_desc'] = 'The image to display as a background of the site.';
$string['backgroundposition'] = 'Background position';
$string['backgroundposition_desc'] = 'The position of the background image.';
$string['backgroundpositioncenterbottom'] = 'Center bottom';
$string['backgroundpositioncentercenter'] = 'Center center';
$string['backgroundpositioncentertop'] = 'Center top';
$string['backgroundpositionleftbottom'] = 'Left bottom';
$string['backgroundpositionleftcenter'] = 'Left center';
$string['backgroundpositionlefttop'] = 'Left top';
$string['backgroundpositionrightbottom'] = 'Right bottom';
$string['backgroundpositionrightcenter'] = 'Right center';
$string['backgroundpositionrighttop'] = 'Right top';
$string['backgroundrepeat'] = 'Background repeat';
$string['backgroundrepeat_desc'] = 'Defines the way the background image will be repeated.';
$string['backgroundrepeatnorepeat'] = 'No repeat';
$string['backgroundrepeatrepeat'] = 'Repeat';
$string['backgroundrepeatrepeatx'] = 'Repeat horizontally';
$string['backgroundrepeatrepeaty'] = 'Repeat vertically';
$string['bodybackground'] = 'Background colour';
$string['bodybackground_desc'] = 'The main colour to use for the background.';
$string['choosereadme'] = '<p>More is a theme that allows you to easily customise Moodle\'s look and feel directly from the web interface.</p>
<p>Visit the admin settings to change colours, add an image as a background, add your logo and more.</p>';

$string['configtitle'] = 'More';
$string['contentbackground'] = 'Main content background colour';
$string['contentbackground_desc'] = 'The background colour of the main content of the site, leave empty for none.';

$string['customcss'] = 'Custom CSS';
$string['customcssdesc'] = 'Whatever CSS rules you add to this textarea will be reflected in every page, making for easier customization of this theme.';

$string['footnote'] = 'Footnote';
$string['footnotedesc'] = 'Whatever you add to this textarea will be displayed in the footer throughout your Moodle site.';

$string['invert'] = 'Invert navbar';
$string['invertdesc'] = 'Swaps text and background for the navbar at the top of the page between black and white.';

$string['linkcolor'] = 'Link colour';
$string['linkcolor_desc'] = 'The colour of the links.';
$string['logo'] = 'Logo';
$string['logodesc'] = 'The logo is only displayed in the header of the front page and login page.<br /> If the height of your logo is more than 75px add div.logo {height: 100px;} to the Custom CSS box below, amending accordingly if the height is other than 100px. If a logo is not added here, the logo in Appearance > Logos will be used.';

$string['pluginname'] = 'More';

$string['region-side-post'] = 'Right';
$string['region-side-pre'] = 'Left';
$string['secondarybackground'] = 'Secondary background colour';
$string['secondarybackground_desc'] = 'The background colour of any secondary content, such as blocks.';
$string['sitelogo'] = 'Site logo';
$string['sitename'] = 'Display site name along with small logo';
$string['sitenamedesc'] = 'If there is no small logo, the site name is always displayed in the navigation bar. If a small logo is set, it may be displayed with or without the site name.';
$string['smalllogo'] = 'Small logo';
$string['smalllogodesc'] = 'The small logo is displayed in the navigation bar. If there is a header logo for the front page and login page, the small logo is not displayed on these pages.  If a logo is not added here, the compact logo in Appearance > Logos will be used.';
$string['textcolor'] = 'Text colour';
$string['textcolor_desc'] = 'The colour of the text.';
